@@ -11,7 +11,7 @@
 
 (defvar yas-snippet-dirs)
 
-(declare-function magit-toplevel "magit" (&optional dir))
+(declare-function ai-code--git-root "ai-code-file" (&optional dir))
 
 (defvar ai-code-use-gptel-headline)
 (defvar ai-code-prompt-suffix)
@@ -21,8 +21,8 @@
 
 (declare-function yas-load-directory "yasnippet" (dir))
 (declare-function yas-minor-mode "yasnippet")
-(declare-function ai-code-cli-send-command "ai-code-interface" (command))
-(declare-function ai-code-cli-switch-to-buffer "ai-code-interface" ())
+(declare-function ai-code-cli-send-command "ai-code-backends" (command))
+(declare-function ai-code-cli-switch-to-buffer "ai-code-backends" ())
 (declare-function gptel-request "gptel" (prompt &rest args))
 (declare-function gptel-abort "gptel" (buffer))
 (declare-function ai-code--git-repo-recent-modified-files "ai-code-git" (base-dir limit))
@@ -206,12 +206,11 @@ The function splits the prompt by whitespace, checks if each part is a file
 path within the current git repository, and if so, replaces it with a
 relative path prefixed with @.
 NOTE: This does not handle file paths containing spaces."
-  (if-let* ((git-root (magit-toplevel)))
-      (let ((git-root-truename (file-truename git-root)))
-        (mapconcat
-         (lambda (word) (ai-code--process-word-for-filepath word git-root-truename))
-         (split-string prompt-text "[ \t\n]+" t) ; split by whitespace and remove empty strings
-         " "))
+  (if-let* ((git-root-truename (ai-code--git-root)))
+      (mapconcat
+       (lambda (word) (ai-code--process-word-for-filepath word git-root-truename))
+       (split-string prompt-text "[ \t\n]+" t) ; split by whitespace and remove empty strings
+       " ")
     ;; Not in a git repo, return original prompt
     prompt-text))
 
@@ -324,9 +323,8 @@ that root, otherwise return the absolute path."
 
 (defun ai-code--prompt-filepath-candidates ()
   "Return file path candidates for prompt completion."
-  (when-let ((git-root (magit-toplevel)))
-    (let* ((git-root-truename (file-truename git-root))
-           (current-file (buffer-file-name (current-buffer)))
+  (when-let ((git-root-truename (ai-code--git-root)))
+    (let* ((current-file (buffer-file-name (current-buffer)))
            (current-frame-dired-paths
             (ai-code--current-frame-dired-paths git-root-truename))
            (visible-files (ai-code--visible-window-files))
@@ -361,7 +359,7 @@ that root, otherwise return the absolute path."
 
 (defun ai-code--prompt-filepath-capf ()
   "Provide completion candidates for @file paths in prompt buffer."
-  (when (and (not (minibufferp)) (magit-toplevel))
+  (when (and (not (minibufferp)) (ai-code--git-root))
     (let ((end (point))
           (start (save-excursion
                    (skip-chars-backward "A-Za-z0-9_./-")
@@ -454,7 +452,7 @@ based on the task name. Otherwise, use cleaned-up task name directly."
   "Get the task directory path.
 If in a git repository, return `.ai.code.files/` under git root.
 Otherwise, return the current `default-directory`."
-  (let ((git-root (magit-toplevel)))
+  (let ((git-root (ai-code--git-root)))
     (if git-root
         (expand-file-name ai-code-files-dir-name git-root)
       default-directory)))
@@ -470,8 +468,8 @@ Otherwise, return the current `default-directory`."
   "Generate a task filename from TASK-NAME.
 If `ai-code-task-use-gptel-filename` is non-nil, use GPTel to generate
 a smart filename. Otherwise, use cleaned-up task name directly.
-If TASK-NAME contains 'rdar://ID', use 'rdar_ID_' as prefix.
-Otherwise, use 'task_YYYYMMDD_' as prefix.
+If TASK-NAME contains `rdar://ID`, use `rdar_ID_` as prefix.
+Otherwise, use `task_YYYYMMDD_` as prefix.
 Returns a filename with .org suffix."
   (let* ((radar-id (when (string-match "rdar://\\([0-9]+\\)" task-name)
                      (match-string 1 task-name)))
@@ -496,6 +494,50 @@ Returns a filename with .org suffix."
       (setq generated-name (substring generated-name 0 60)))
     (concat prefix generated-name ".org")))
 
+(defun ai-code--initialize-task-file-content (task-name task-url)
+  "Insert initial task content using TASK-NAME and TASK-URL."
+  (insert (format "#+TITLE: %s\n" task-name))
+  (insert (format "#+DATE: %s\n" (format-time-string "%Y-%m-%d")))
+  (unless (string-empty-p task-url)
+    (insert (format "#+URL: %s\n" task-url)))
+  (let ((label (ai-code-current-backend-label)))
+    (insert (format "#+AGENT: %s\n" label))
+    (insert "#+SESSION_ID: <Usually you can get the session id with /status or /stat in AI coding window>\n"))
+  (insert "\n* Task Description\n\n")
+  (insert task-name)
+  (insert "\n\n* Investigation\n\n")
+  (insert "# Enter your prompts here. After that,\n# Select them and use C-c a SPC (ai-code-send-command) to send to AI\n\n")
+  (insert "# Use C-c a n (ai-code-take-notes) to copy notes back from AI session\n\n")
+  (insert "\n\n* Code Change\n\n"))
+
+(defun ai-code--open-or-create-task-file (task-file confirmed-filename task-name task-url)
+  "Open TASK-FILE and initialize it when needed.
+CONFIRMED-FILENAME determines if .org should be appended.
+TASK-NAME and TASK-URL are used to initialize new files."
+  (unless (string-suffix-p ".org" confirmed-filename)
+    (setq task-file (concat task-file ".org")))
+  (find-file-other-window task-file)
+  (unless (file-exists-p task-file)
+    (ai-code--initialize-task-file-content task-name task-url))
+  (message "Opened task file: %s" task-file))
+
+(defun ai-code--select-task-target-directory (ai-code-files-dir current-dir)
+  "Prompt user to select target directory.
+
+AI-CODE-FILES-DIR is the path to the .ai.code.files directory.
+CURRENT-DIR is the current default directory.
+
+Returns the selected directory path."
+  (let ((target-dir (completing-read
+                     "Create task file in: "
+                     (list (format "ai-code-files-dir: %s" ai-code-files-dir)
+                           (format "current directory: %s" current-dir))
+                     nil t nil nil
+                     (format "ai-code-files-dir: %s" ai-code-files-dir))))
+    (if (string-prefix-p "ai-code-files-dir:" target-dir)
+        ai-code-files-dir
+      current-dir)))
+
 ;;;###autoload
 (defun ai-code-create-or-open-task-file ()
   "Create or open an AI task file.
@@ -505,36 +547,24 @@ using GPTel, and creates the task file."
   (interactive)
   (let ((task-name (read-string "Task name (empty to open task directory): ")))
     (if (string-empty-p task-name)
-        ;; Open the task directory
         (let ((ai-code-files-dir (ai-code--ensure-files-directory)))
           (dired-other-window ai-code-files-dir)
           (message "Opened task directory: %s" ai-code-files-dir))
-      ;; Create a new task file
       (let* ((task-url (read-string "URL (optional, press Enter to skip): "))
              (ai-code-files-dir (ai-code--ensure-files-directory))
              (generated-filename (ai-code--generate-task-filename task-name))
-             (confirmed-filename (read-string "Confirm task filename: " generated-filename))
-             (task-file (expand-file-name confirmed-filename ai-code-files-dir)))
-        ;; Ensure filename has .org extension
-        (unless (string-suffix-p ".org" confirmed-filename)
-          (setq task-file (concat task-file ".org")))
-        (find-file-other-window task-file)
-        (unless (file-exists-p task-file)
-          ;; Initialize new task file
-          (insert (format "#+TITLE: %s\n" task-name))
-          (insert (format "#+DATE: %s\n" (format-time-string "%Y-%m-%d")))
-          (unless (string-empty-p task-url)
-            (insert (format "#+URL: %s\n" task-url)))
-          (let ((label (ai-code-current-backend-label)))
-            (insert (format "#+AGENT: %s\n" label))
-            (insert "#+SESSION_ID: <Usually you can get the session id with /status or /stat in AI coding window>\n"))
-          (insert "\n* Task Description\n\n")
-          (insert task-name)
-          (insert "\n\n* Investigation\n\n")
-          (insert "# Enter your prompts here. After that,\n# Select them and use C-c a SPC (ai-code-send-command) to send to AI\n\n")
-          (insert "# Use C-c a n (ai-code-take-notes) to copy notes back from AI session\n\n")
-          (insert "\n\n* Code Change\n\n"))
-        (message "Opened task file: %s" task-file)))))
+             (confirmed-filename (read-string "Confirm task filename (end with / to create subdirectory): " generated-filename))
+             (current-dir (expand-file-name default-directory))
+             (selected-dir (ai-code--select-task-target-directory ai-code-files-dir current-dir))
+             (create-dir-only-p (string-suffix-p "/" confirmed-filename))
+             (task-file (expand-file-name confirmed-filename selected-dir)))
+        (if create-dir-only-p
+            (let ((subdir (expand-file-name (directory-file-name confirmed-filename) selected-dir)))
+              (unless (file-directory-p subdir)
+                (make-directory subdir t))
+              (dired-other-window subdir)
+              (message "Opened directory: %s" subdir))
+          (ai-code--open-or-create-task-file task-file confirmed-filename task-name task-url))))))
 
 ;;;###autoload
 (add-to-list 'auto-mode-alist
