@@ -1,8 +1,8 @@
-;;; ai-code.el --- Unified interface for AI coding CLI such as Claude Code, Codex CLI, Gemini CLI, Copilot CLI, Opencode, Grok CLI, Aider CLI, etc -*- lexical-binding: t; -*-
+;;; ai-code.el --- Unified interface for AI coding backends such as Claude Code, Codex CLI, Gemini CLI, Copilot CLI, Opencode, Grok CLI, Aider CLI, agent-shell, etc -*- lexical-binding: t; -*-
 
 ;; Author: Kang Tu <tninja@gmail.com>
-;; Package-Version: 20260216.226
-;; Package-Revision: 69641032b816
+;; Package-Version: 20260218.250
+;; Package-Revision: 9e4d5cb2dc08
 ;; Package-Requires: ((emacs "28.1") (transient "0.8.0") (magit "2.1.0"))
 ;; URL: https://github.com/tninja/ai-code-interface.el
 
@@ -27,12 +27,13 @@
 ;;   - Kiro CLI
 ;;   - CodeBuddy Code CLI
 ;;   - Aider CLI
+;;   - agent-shell
 ;;
 ;; Basic configuration example:
 ;;
 ;; (use-package ai-code
 ;;   :config
-;;   ;; use codex as backend, other options are 'gemini, 'github-copilot-cli, 'opencode, 'grok, 'claude-code-ide, 'claude-code-el, 'claude-code, 'cursor, 'kiro, 'codebuddy, 'aider
+;;   ;; use codex as backend, other options are 'gemini, 'github-copilot-cli, 'opencode, 'grok, 'claude-code-ide, 'claude-code-el, 'claude-code, 'cursor, 'kiro, 'codebuddy, 'aider, 'agent-shell
 ;;   (ai-code-set-backend 'codex) ;; set your preferred backend
 ;;   (global-set-key (kbd "C-c a") #'ai-code-menu)
 ;;   ;; Optional: Enable @ file completion in comments and AI sessions
@@ -360,7 +361,7 @@ Shows the current backend label to the right."
     ("q" "Ask question (C-u: clipboard)" ai-code-ask-question)
     ("x" "Explain code in scope" ai-code-explain)
     ("<SPC>" "Send command (C-u: context)" ai-code-send-command)
-    ("@" "Add context (C-u: clear)" ai-code-context-action)
+    ("@" "Context (add/show/clear)" ai-code-context-action)
     ("C" "Create file or dir with AI" ai-code-create-file-or-dir)
     ]
 
